MODULE c1d
   !!======================================================================
   !!                     ***  MODULE  c1d  ***
   !! Ocean domain  :  1D configuration
   !!=====================================================================
   !! History :   2.0  !  2004-09 (C. Ethe)     Original code
   !!             3.0  !  2008-04 (G. Madec)    adaptation to SBC
   !!             3.5  !  2013-10 (D. Calvert)  add namelist
   !!----------------------------------------------------------------------
#if defined key_c1d
   !!----------------------------------------------------------------------
   !!   'key_c1d'                                   1D column configuration
   !!----------------------------------------------------------------------
   !!   c1d_init       : read in the C1D namelist
   !!----------------------------------------------------------------------
   USE in_out_manager   ! I/O manager
   USE par_kind         ! kind parameters

   IMPLICIT NONE
   PRIVATE

   PUBLIC   c1d_init                                 ! called by nemogcm.F90

   LOGICAL , PUBLIC, PARAMETER ::  lk_c1d = .TRUE.   ! 1D config. flag

   REAL(wp), PUBLIC            ::  rn_lat = 50       ! Column latitude
   REAL(wp), PUBLIC            ::  rn_lon = -145     ! Column longitude

   !!----------------------------------------------------------------------
   !! NEMO/C1D 3.3 , NEMO Consortium (2010)
   !! $Id: c1d.F90 2382 2010-11-13 13:08:12Z gm $ 
   !! Software governed by the CeCILL licence     (NEMOGCM/NEMO_CeCILL.txt)
   !!======================================================================
CONTAINS

   SUBROUTINE c1d_init
      !!----------------------------------------------------------------------
      !!                  ***  ROUTINE c1d_init  ***
      !! 
      !! ** Purpose :   Initialization of C1D options
      !!
      !! ** Method  :   Read namelist namc1d 
      !!----------------------------------------------------------------------
      NAMELIST/namc1d/ rn_lat, rn_lon
      !!----------------------------------------------------------------------
      !
      REWIND ( numnam )               ! Read C1D options from namelist
      READ   ( numnam, namc1d )
      !
      IF(lwp) THEN                    ! Control print
         WRITE(numout,*)
         WRITE(numout,*) 'c1d_init : Initialize 1D model configuration options'
         WRITE(numout,*) '~~~~~~~~'
         WRITE(numout,*) '   Namelist namc1d : set options for the C1D model'
         WRITE(numout,*) '      column latitude                 rn_lat = ', rn_lat
         WRITE(numout,*) '      column longitude                rn_lon = ', rn_lon
      ENDIF
      !
      !
   END SUBROUTINE c1d_init

#else
   !!----------------------------------------------------------------------
   !!   Dummy module :                           No use of 1D configuration
   !!----------------------------------------------------------------------
   LOGICAL, PUBLIC, PARAMETER ::   lk_c1d = .FALSE.   !: 1D config. flag de-activated
   REAL                       ::   rn_lat, rn_lon
CONTAINS

   SUBROUTINE c1d_init               ! Dummy routine
   END SUBROUTINE c1d_init

#endif

   !!======================================================================
END MODULE c1d
